%bcond_without  junit5

Name:           maven-surefire
Version:        2.22.0
Release:        %mkrel 4
Group:          Development/Java
Epoch:          0
Summary:        Test framework project
License:        ASL 2.0 and CPL
URL:            http://maven.apache.org/surefire/
BuildArch:      noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# Remove bundled binaries which cannot be easily verified for licensing
Source1:        generate-tarball.sh
Source2:        http://junit.sourceforge.net/cpl-v10.html

Patch0:         0001-Maven-3.patch
Patch1:         0002-Port-to-current-doxia.patch
Patch2:         0003-Port-to-TestNG-6.11.patch
Patch3:         0004-Port-to-current-maven-shared-utils.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-site-renderer)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-parent:pom:)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-failsafe-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-invoker-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
BuildRequires:  mvn(org.apache.maven.shared:maven-common-artifact-filters)
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-utils)
BuildRequires:  mvn(org.apache.maven.shared:maven-verifier)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.codehaus.plexus:plexus-java)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.fusesource.jansi:jansi)
BuildRequires:  mvn(org.testng:testng)
BuildRequires:  mvn(org.testng:testng::jdk15:)

%if %{with junit5}
BuildRequires:  mvn(org.junit.platform:junit-platform-launcher)
%endif

# PpidChecker relies on /usr/bin/ps to check process uptime
Requires:       procps-ng

%description
Surefire is a test framework project.

%package plugin
Summary:                Surefire plugin for maven

%description plugin
Maven surefire plugin for running tests via the surefire framework.

%package report-plugin
Summary:                Surefire reports plugin for maven

%description report-plugin
Plugin for generating reports from surefire test runs.

%package provider-junit
Summary:                JUnit provider for Maven Surefire

%description provider-junit
JUnit provider for Maven Surefire.

%if %{with junit5}
%package provider-junit5
Summary:                JUnit 5 provider for Maven Surefire

%description provider-junit5
JUnit 5 provider for Maven Surefire.
%endif

%package provider-testng
Summary:                TestNG provider for Maven Surefire

%description provider-testng
TestNG provider for Maven Surefire.

%package report-parser
Summary:                Parses report output files from surefire

%description report-parser
Plugin for parsing report output files from surefire.

%package -n maven-failsafe-plugin
Summary:                Maven plugin for running integration tests

%description -n maven-failsafe-plugin
The Failsafe Plugin is designed to run integration tests while the
Surefire Plugins is designed to run unit. The name (failsafe) was
chosen both because it is a synonym of surefire and because it implies
that when it fails, it does so in a safe way.

If you use the Surefire Plugin for running tests, then when you have a
test failure, the build will stop at the integration-test phase and
your integration test environment will not have been torn down
correctly.

The Failsafe Plugin is used during the integration-test and verify
phases of the build lifecycle to execute the integration tests of an
application. The Failsafe Plugin will not fail the build during the
integration-test phase thus enabling the post-integration-test phase
to execute.

%package javadoc
Summary:          Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n surefire-%{version}
cp -p %{SOURCE2} .

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Disable strict doclint
sed -i /-Xdoclint:all/d pom.xml

%pom_disable_module surefire-shadefire

%if %{without junit5}
%pom_disable_module surefire-junit-platform surefire-providers
%endif

%pom_remove_dep -r org.apache.maven.surefire:surefire-shadefire

# Help plugin is needed only to evaluate effective Maven settings.
# For building RPM package default settings will suffice.
%pom_remove_plugin :maven-help-plugin surefire-setup-integration-tests

# QA plugin useful only for upstream
%pom_remove_plugin -r :jacoco-maven-plugin

# Not in Fedora
%pom_remove_plugin -r :animal-sniffer-maven-plugin
# Complains
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
# We don't need site-source
%pom_remove_plugin :maven-assembly-plugin maven-surefire-plugin
%pom_remove_dep -r ::::site-source

%pom_xpath_set pom:mavenVersion 3.3.3
%pom_remove_dep :maven-project maven-surefire-report-plugin
%pom_remove_dep :maven-project maven-surefire-common
%pom_remove_dep :maven-plugin-descriptor maven-surefire-common
%pom_remove_dep :maven-toolchain maven-surefire-common

%pom_xpath_remove -r "pom:execution[pom:id='shared-logging-generated-sources']"

%pom_add_dep com.google.code.findbugs:jsr305 surefire-api

# This package needs maven compat for ArtifactResolver class
%pom_add_dep org.apache.maven:maven-compat maven-surefire-common

%build
%mvn_package ":*{surefire-plugin,report-plugin}*" @1
%mvn_package ":*junit-platform*" junit5
%mvn_package ":*{junit,testng,failsafe-plugin,report-parser}*"  @1
%mvn_package ":*tests*" __noinstall
# tests turned off because they need jmock
# use xmvn-javadoc because maven-javadoc-plugin crashes JVM
%mvn_build -f -j -G org.fedoraproject.xmvn:xmvn-mojo:javadoc

%install
%mvn_install


%files -f .mfiles
%doc README.md
%license LICENSE NOTICE cpl-v10.html

%files plugin -f .mfiles-surefire-plugin
%files report-plugin -f .mfiles-report-plugin
%files report-parser -f .mfiles-report-parser
%files provider-junit -f .mfiles-junit
%files provider-testng -f .mfiles-testng
%files -n maven-failsafe-plugin -f .mfiles-failsafe-plugin
%if %{with junit5}
%files provider-junit5 -f .mfiles-junit5
%endif

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE cpl-v10.html



%changelog
* Wed Aug 19 2020 neoclust <neoclust> 0:2.22.0-4.mga8
+ Revision: 1616333
- Add maven-compat dependency in maven-surefire-common for ArtifactResolver class

* Fri Feb 14 2020 umeabot <umeabot> 0:2.22.0-3.mga8
+ Revision: 1520676
- Mageia 8 Mass Rebuild

* Tue Dec 04 2018 daviddavid <daviddavid> 0:2.22.0-2.mga7
+ Revision: 1338325
- enable new junit5 support

* Mon Nov 26 2018 guillomovitch <guillomovitch> 0:2.22.0-1.mga7
+ Revision: 1335578
- new version 2.22.0

* Thu Sep 20 2018 daviddavid <daviddavid> 0:2.19.1-7.mga7
+ Revision: 1287481
- Port to TestNG 6.11
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon May 15 2017 neoclust <neoclust> 0:2.19.1-6.mga6
+ Revision: 1101393
- Rebuild maven-* packages

* Tue May 09 2017 neoclust <neoclust> 0:2.19.1-5.mga6
+ Revision: 1099806
- Compile against Maven 3 APIs
- Second rebuild of the java stack

* Fri Feb 26 2016 neoclust <neoclust> 0:2.19.1-2.mga6
+ Revision: 979377
- First rebuild of the java stack
- sync package maven-surefire with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 0:2.17-2.mga5
+ Revision: 805731
- Clean rebuild
- Sync with Fedora 21 (and update to 2.17)

* Wed Oct 15 2014 umeabot <umeabot> 0:2.16-5.mga5
+ Revision: 746567
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Mon May 19 2014 dmorgan <dmorgan> 0:2.16-3.mga5
+ Revision: 623753
- Fix file list

* Mon May 19 2014 dmorgan <dmorgan> 0:2.16-2.mga5
+ Revision: 623749
- Rebuild against fixed maven-local

* Mon May 19 2014 dmorgan <dmorgan> 0:2.16-1.mga5
+ Revision: 623738
- New version

* Sat Oct 19 2013 umeabot <umeabot> 0:2.15-3.mga4
+ Revision: 535157
- Mageia 4 Mass Rebuild
+ dmorgan <dmorgan>
- Rebuild against new javapackages

* Thu Sep 19 2013 dmorgan <dmorgan> 0:2.15-1.mga4
+ Revision: 481389
- New version 2.15

* Tue Sep 17 2013 dmorgan <dmorgan> 0:2.13-4.mga4
+ Revision: 481035
- Add missing BR: mockito

* Sat Jul 13 2013 dmorgan <dmorgan> 0:2.13-3.mga4
+ Revision: 453715
- Migrated from maven-doxia to doxia subpackages (Resolves: #889149)

* Fri Jul 12 2013 dmorgan <dmorgan> 0:2.13-2.mga4
+ Revision: 453585
- Get rid of custom depmap

* Thu Jul 11 2013 dmorgan <dmorgan> 0:2.13-1.mga4
+ Revision: 452936
- New version
- Newer versions of xmvn macros require arguments to be quoted.
- Build with xmvn
- Add CPL license

* Sat Jan 12 2013 umeabot <umeabot> 0:2.12.4-4.mga3
+ Revision: 359800
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 15 2012 pterjan <pterjan> 0:2.12.4-3.mga3
+ Revision: 331240
- Add missing dependency

* Mon Dec 03 2012 dmorgan <dmorgan> 0:2.12.4-2.mga3
+ Revision: 326002
- Java Stack Mass Rebuild
- New version
- New version

* Mon Dec 03 2012 dmorgan <dmorgan> 0:2.12-5.mga3
+ Revision: 325712
- Java Stack Mass Rebuild
- New version 2.12.4

* Fri Oct 26 2012 dmorgan <dmorgan> 0:2.12-4.mga3
+ Revision: 310572
- Rebuild with java7
- New version
- New version

* Wed Sep 12 2012 dmorgan <dmorgan> 0:2.12-3.mga3
+ Revision: 292978
- Fix build problem and rebuild with target 1.5

* Mon Jul 09 2012 dmorgan <dmorgan> 0:2.12-2.mga3
+ Revision: 269111
- Rebuild in non bootstrap mode

* Mon Jul 09 2012 dmorgan <dmorgan> 0:2.12-1.mga3
+ Revision: 269093
- New version 2.12 ( in bootstrap mode)

* Thu Jan 05 2012 dmorgan <dmorgan> 0:2.10-4.mga2
+ Revision: 191844
- Add missing patch
- Fix macros

* Sun Dec 25 2011 dmorgan <dmorgan> 0:2.10-2.mga2
+ Revision: 187644
+ rebuild (emptylog)

* Tue Jul 19 2011 dmorgan <dmorgan> 0:2.8.1-2.mga2
+ Revision: 126272
- Fix up providers artifact and report plugin groupid
- Fix maven-surefire-plugin group in the depmap.(fedora)
- Install testng-utils jar and pom

* Tue Jul 19 2011 dmorgan <dmorgan> 0:2.8.1-1.mga2
+ Revision: 126128
- Update to latest upstream version (2.8.1)

* Thu Apr 28 2011 dmorgan <dmorgan> 0:2.8-2.mga1
+ Revision: 92935
- Rebuild after bootstrapping
- imported package maven-surefire


* Tue Mar 29 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:2.8-1
- Update to latest upstream version (2.8)

* Mon Mar  7 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:2.7.2-1
- Update to latest version (2.7.2)
- Add common-junit* jars to distribution
- Versionless javadocs
- Use maven 3 to build

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:2.7.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jan 3 2011 Alexander Kurtakov <akurtako@redhat.com> 0:2.7.1-2
- Fix junit3 depmap.

* Wed Dec 29 2010 Alexander Kurtakov <akurtako@redhat.com> 0:2.7.1-1
- Update to 2.7.1.

* Wed Dec  8 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:2.6-3
- Add proper Requires on junit/junit4/testng to providers

* Fri Oct 29 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:2.6-2
- Add main pom.xml

* Mon Aug 30 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:2.6-1
- Rename subpackages to not repeat "maven" twice
- Update to latest upstream version
- Add common jar to files
- Introduce maven-failsafe-plugin sub-package
- Cleanups

* Mon Aug 31 2009 Andrew Overholt <overholt@redhat.com> 0:2.3-7.7
- Bump release to rebuild

* Mon Aug 31 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.6
- Really remove maven2-plugin-surefire BR.

* Mon Aug 31 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.5
- Revert previous change.

* Mon Aug 31 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.4
- Disable not needed BRs.

* Mon Aug 31 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.3
- Install JPP.maven2.plugins-surefire-plugin.pom now that we have maven 2.0.8.

* Wed Aug 19 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.2
- Don't install JPP.maven2.plugins-surefire-plugin.pom to fix conflict with maven2 2.0.4.

* Tue Aug 18 2009 Alexander Kurtakov <akurtako@redhat.com> 0:2.3-7.1
- Update to 2.3 - sync with jpackage.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.5.3-4.8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.5.3-3.8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Aug 13 2008 Deepak Bhole <dbhole@redhat.com> 1.5.3-2.8
- Build for ppc64

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.5.3-2.7
- drop repotag

* Thu May 29 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.5.3-2jpp.6
- fix license tag

* Thu Feb 28 2008 Deepak Bhole <dbhole@redhat.com> 1.5.3-2jpp.5
- Rebuild

* Fri Sep 21 2007 Deepak Bhole <dbhole@redhat.com> 1.5.3-2jpp.4
- Build with maven
- ExcludeArch ppc64

* Fri Aug 31 2007 Deepak Bhole <dbhole@redhat.com> 0:1.5.3-2jpp.3
- Build without maven (for initial ppc build)

* Tue Mar 20 2007 Deepak Bhole <dbhole@redhat.com> 0:1.5.3-2jpp.2
- Build with maven

* Mon Feb 26 2007 Tania Bento <tbento@redhat.com> 0:1.5.3-2jpp.1
- Fixed %%Release.
- Fixed %%BuildRoot.
- Removed %%Vendor.
- Removed %%Distribution.
- Removed period at the end of %%Summary.
- Removed %%post and %%postun sections for javadoc.
- Removed %%post and %%postun sections for booter-javadoc.
- Added gcj support option.
- Fixed instructions on how to generate source drop.

* Tue Oct 17 2006 Deepak Bhole <dbhole@redhat.com> 1.5.3-2jpp
- Update for maven2 9jpp

* Mon Jun 19 2006 Deepak Bhole <dbhole@redhat.com> - 0:1.5.3-1jpp
- Initial build
